==> legato-dist-core-1.1.2-dist.zip: Legato-Core-1.1.2/lib/Legato/Handler/Point.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

Legato.Handler.Point = OpenLayers.Class(OpenLayers.Handler.Point, {
  geometryClone : function() {
    var originalGeometry = this.point && this.point.geometry;
    if (originalGeometry) {
      var originalGeometryId = originalGeometry.id;
      originalGeometry.id = OpenLayers.Util.createUniqueID(originalGeometry.CLASS_NAME+ "_");
      var clonedGeometry = originalGeometry.clone();
      clonedGeometry.id = originalGeometryId; 
      this.point.geometry = clonedGeometry;
      if (this.multi) {
        return new OpenLayers.Geometry.MultiPoint([ originalGeometry ]);
      } else {
        return originalGeometry;
      }
    }
    return originalGeometry;
  },
  CLASS_NAME : "Legato.Handler.Point"
});

==> legato-dist-core-1.3.0-dist.zip: Legato-Core-1.3.0/lib/Legato/Handler/Point.js <==
/*
 * Legato is a configurable, lightweight web mapping client that can be
 * easily embedded into web pages and portals, CMS and individual web
 * applications. Legato is implemented in JavaScript and based on the
 * popular open source library OpenLayers.
 *
 * Copyright (C) 2010  disy Informationssysteme GmbH, http://www.disy.net
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

Legato.Handler.Point = OpenLayers.Class(OpenLayers.Handler.Point, {
  initialize: function(control, callbacks, options) {
    var opts = options;
    if (!options) {
      opts = {};
    }
    if (!opts.layerOptions) {
      opts.layerOptions = {};
    }
    opts.layerOptions.legatoIgnore = true;
    OpenLayers.Handler.Point.prototype.initialize.apply(this, [control, callbacks, opts]);
  },
  geometryClone : function() {
    var originalGeometry = this.point && this.point.geometry;
    if (originalGeometry) {
      var originalGeometryId = originalGeometry.id;
      originalGeometry.id = OpenLayers.Util.createUniqueID(originalGeometry.CLASS_NAME+ "_");
      var clonedGeometry = originalGeometry.clone();
      clonedGeometry.id = originalGeometryId;
      this.point.geometry = clonedGeometry;
      if (this.multi) {
        return new OpenLayers.Geometry.MultiPoint([ originalGeometry ]);
      } else {
        return originalGeometry;
      }
    }
    return originalGeometry;
  },
  CLASS_NAME : "Legato.Handler.Point"
});
